# python gantt lib

This project is an extension of the `python-gantt`module, providing some extra functionality.
This includes some translation to spanish of the days and months, new classes for add hyperlinks to the tasks and projects, and svg in format string for using it as context in Django lib.

## Instalation

Run the following to install:

```python
pip install gantt-lib
```

## Usage
```python

```
# TODO
 